spec_plots
==========
| Main Branch |
| :-----------: |
| [![Documentation Status](https://readthedocs.org/projects/spec-plots/badge/?version=main)](https://readthedocs.org/projects/spec-plots/?badge=main) |

Generates spectroscopic preview plots for MAST missions.  Full documentation available at [Read the Docs](https://readthedocs.org/projects/spec-plots/).
